@@ -41,7 +41,7 @@ use Scalar::Util qw{ refaddr weaken };
 
 use PPIx::Regexp::Constant qw{ $MINIMUM_PERL };
 
-our $VERSION = '0.005';
+our $VERSION = '0.008';
 
 =head2 ancestor_of
 
@@ -61,6 +61,18 @@ sub ancestor_of {
     return 1;
 }
 
+=head2 can_be_quantified
+
+ $token->can_be_quantified()
+     and print "This element can be quantified.\n";
+
+This method returns true if the element can be quantified.
+
+=cut
+
+sub can_be_quantified { return 1; }
+
+
 =head2 class
 
 This method returns the class name of the element. It is the same as
@@ -108,6 +120,21 @@ sub descendant_of {
     return $node->ancestor_of( $self );
 }
 
+
+=head2 is_quantifier
+
+ $token->is_quantifier()
+     and print "This element is a quantifier.\n";
+
+This method returns true if the element is a quantifier. You can not
+tell this from the element's class, because a right curly bracket may
+represent a quantifier for the purposes of figuring out whether a
+greediness token is possible.
+
+=cut
+
+sub is_quantifier { return; }
+
 =head2 next_sibling
 
 This method returns the element's next sibling, or nothing if there is
@@ -355,7 +382,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009, Thomas R. Wyant, III
+Copyright (C) 2009-2010, Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
